/*
 *  linux/include/asm-arm/arch-clps711x/irqs.h
 *
 *  Copyright (C) 2000 Deep Blue Solutions Ltd.
 *  Copyright (C) 2001-2003 Atmark Techno, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __ASM_ARCH_IRQS_H
#define __ASM_ARCH_IRQS_H

/*
 * Interrupts from INTSR1
 */
#define IRQ_CSINT			4
#define IRQ_EINT1			5
#define IRQ_EINT2			6
#define IRQ_EINT3			7
#define IRQ_TC1OI			8
#define IRQ_TC2OI			9
#define IRQ_RTCMI			10
#define IRQ_TINT			11
#define IRQ_UTXINT1			12
#define IRQ_URXINT1			13
#define IRQ_UMSINT			14
#define IRQ_SSEOTI			15

#define INT1_IRQS			(0x0000fff0)
#define INT1_ACK_IRQS			(0x00004f10)

/*
 * Interrupts from INTSR2
 */
#define IRQ_KBDINT			(16+0)	/* bit 0 */
#define IRQ_SS2RX			(16+1)	/* bit 1 */
#define IRQ_SS2TX			(16+2)	/* bit 2 */
#define IRQ_UTXINT2			(16+12)	/* bit 12 */
#define IRQ_URXINT2			(16+13)	/* bit 13 */

#define INT2_IRQS			(0x30070000)
#define INT2_ACK_IRQS			(0x00010000)

#define NR_IRQS_IRQ                     30

#ifdef CONFIG_ARCH_ARMADILLO

#define IRQ_ISA_BASE                    NR_IRQS_IRQ

#define IRQ_ISA3                        (IRQ_ISA_BASE)
#define IRQ_ISA4                        (IRQ_ISA_BASE + 1)
#define IRQ_ISA5                        (IRQ_ISA_BASE + 2)
#define IRQ_ISA6                        (IRQ_ISA_BASE + 3)

#define INTISA3_IRQS                    (0x0000000f)

#define IRQ_ISA7                        (IRQ_ISA_BASE + 4)
#define IRQ_ISA9                        (IRQ_ISA_BASE + 5)
#define IRQ_ISA10                       (IRQ_ISA_BASE + 6)
#define IRQ_ISA11                       (IRQ_ISA_BASE + 7)

#define INTISA2_IRQS                    (0x000000f0)

#define IRQ_ISA12                       (IRQ_ISA_BASE + 8)
#define IRQ_IDE                         (IRQ_ISA_BASE + 9)
#define IRQ_ISA15                       (IRQ_ISA_BASE + 10)

#define INTISA1_IRQS                    (0x00000700)

#define NR_IRQS_ISA                     41

#ifndef __ASSEMBLY__

static __inline__ unsigned int convirq_to_isa (unsigned int irq)
{
  switch (irq) {
  case IRQ_ISA3:
    return 3;
  case IRQ_ISA4:
    return 4;
  case IRQ_ISA5:
    return 5;
  case IRQ_ISA6:
    return 6;
  case IRQ_ISA7:
    return 7;
  case IRQ_ISA9:
    return 9;
  case IRQ_ISA10:
    return 10;
  case IRQ_ISA11:
    return 11;
  case IRQ_ISA12:
    return 12;
  case IRQ_ISA15:
    return 15;
  }
  
  return 0;
}

static __inline__ unsigned int convirq_from_isa (unsigned int irq)
{
  switch (irq) {
  case 3:
    return IRQ_ISA3;
  case 4:
    return IRQ_ISA4;
  case 5:
    return IRQ_ISA5;
  case 6:
    return IRQ_ISA6;
  case 7:
    return IRQ_ISA7;
  case 9:
    return IRQ_ISA9;
  case 10:
    return IRQ_ISA10;
  case 11:
    return IRQ_ISA11;
  case 12:
    return IRQ_ISA12;
  case 15:
    return IRQ_ISA15;
  }
  
  return 0;
}

#endif

#endif

#ifdef CONFIG_FIQ

#define FIQ_START                       64

#define FIQ_EXTFIQ                      0
#define FIQ_BLINT                       1
#define FIQ_WEINT                       2
#define FIQ_MCINT                       3

#define FIQ1_IRQS                      (0x0000000f)
#define FIQ1_ACK_IRQS                  (0x0000000a)

#define FIQ_DAIINT                      8

#define FIQ3_IRQS                      (0x00000100)

#define NR_IRQS_FIQ                     73

#define NR_IRQS                         NR_IRQS_FIQ

#else

#ifdef CONFIG_ARCH_ARMADILLO

#define NR_IRQS                         NR_IRQS_ISA

#else

#define NR_IRQS                         NR_IRQS_IRQ

#endif

#endif

#endif
